CommandHolder (Selenium RC Server (Coreless) 1.0.1 API)
Date: 2009-06-09

Overview | Package | Class | Use | Tree | Deprecated | Index | Help
PREV CLASS NEXT CLASS | FRAMES NO FRAMES
SUMMARY: NESTED | FIELD | CONSTR | METHOD | DETAIL: FIELD | CONSTR | METHOD

## org.openqa.selenium.server
Class CommandHolder

    java.lang.Object
      org.openqa.selenium.server.CommandHolder

    public class CommandHolder

extends java.lang.Object

Holds the command to be next run in the browser

Version:
  $Revision: 734 $
Author:
  Jennifer Bevan

Field Summary
`protected static java.lang.String` | `RETRY_CMD_STRING`
`protected static RemoteCommand` | `retryCommand`

Constructor Summary
`CommandHolder(java.lang.String queueId)`
`CommandHolder(java.lang.String queueId, int timeoutInSeconds)`

Method Summary
`RemoteCommand` | `getCommand()` Get, and remove from the holder, the next command to run.
`boolean` | `isEmpty()`
`RemoteCommand` | `peek()`
`void` | `poisonPollers()`
`boolean` | `putCommand(RemoteCommand cmd)`

Methods inherited from class java.lang.Object
`clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait`

Field Detail

### RETRY_CMD_STRING

    protected static final java.lang.String RETRY_CMD_STRING

See Also:
  Constant Field Values

### retryCommand

    protected static final RemoteCommand retryCommand

Constructor Detail

### CommandHolder

    public CommandHolder(java.lang.String queueId)

### CommandHolder

    public CommandHolder(java.lang.String queueId,
                         int timeoutInSeconds)

Method Detail

### getCommand

    public RemoteCommand getCommand()

  Get, and remove from the holder, the next command to run. If the next command doesn't show up within timeoutInSeconds seconds, then return a "retry" command.

  Returns:
    the next command to execute.

### putCommand

    public boolean putCommand(RemoteCommand cmd)

### isEmpty

    public boolean isEmpty()

### peek

    public RemoteCommand peek()

### poisonPollers

    public void poisonPollers()

Overview | Package | Class | Use | Tree | Deprecated | Index | Help
PREV CLASS NEXT CLASS | FRAMES NO FRAMES
SUMMARY: NESTED | FIELD | CONSTR | METHOD | DETAIL: FIELD | CONSTR | METHOD

Copyright © 2009. All Rights Reserved.